@@ -691,7 +691,7 @@ static void add_global_worklist(struct widget *pwidget)
 
     /* Global worklist can have targets unavilable in current state of game
        then we must remove those targets from new city worklist */
-    if (!can_city_build_later(editor->pcity, &pworklist->entries[count])) {
+    if (!can_city_build_later(&(wld.map), editor->pcity, &pworklist->entries[count])) {
       continue;
     }
 
@@ -769,7 +769,7 @@ static void set_global_worklist(struct widget *pwidget)
   for (count = 0; count < worklist_length(pworklist); count++) {
     /* global worklist can have targets unavilable in current state of game
        then we must remove those targets from new city worklist */
-    if (!can_city_build_later(editor->pcity, &pworklist->entries[count])) {
+    if (!can_city_build_later(&(wld.map), editor->pcity, &pworklist->entries[count])) {
       continue;
     }
 
@@ -1066,6 +1066,7 @@ void popup_worklist_editor(struct city *pcity, struct global_worklist *gwl)
   bool can_build, can_eventually_build;
   SDL_Rect area;
   int len;
+  const struct civ_map *nmap = &(wld.map);
 
   if (editor) {
     return;
@@ -1558,9 +1559,9 @@ void popup_worklist_editor(struct city *pcity, struct global_worklist *gwl)
 
     /* If there's a city, can the city build the unit? */
     if (pcity) {
-      can_build = can_build && can_city_build_unit_now(pcity, un);
+      can_build = can_build && can_city_build_unit_now(nmap, pcity, un);
       can_eventually_build = can_eventually_build
-        && can_city_build_unit_later(pcity, un);
+        && can_city_build_unit_later(nmap, pcity, un);
     }
 
     if ((advanced_tech && can_eventually_build)
